smartcard.pcsc.PCSCExceptions.RemoveReaderFromGroupException

# ``smartcard`.`pcsc`.`PCSCExceptions`.`RemoveReaderFromGroupException``

exception documentation

`class RemoveReaderFromGroupException(BaseSCardException):`

View In Hierarchy

Raised when scard fails to remove a reader from a PCSC reader group.

Method | `__init__` | Constructor that stores the pcsc error status.
Instance Variable | `groupname` | Undocumented
Instance Variable | `readername` | Undocumented

Inherited from `BaseSCardException`:

Method | `__str__` | Returns a string representation of the exception.
Instance Variable | `hresult` | Undocumented
Instance Variable | `message` | Undocumented

def __init__(self, hresult, readername='', groupname=''):
overrides `smartcard.pcsc.PCSCExceptions.BaseSCardException.__init__`

Constructor that stores the pcsc error status.

groupname =

Undocumented

readername =

Undocumented